//
//	Copyright  Nemetschek Vectorworks, Inc.
//	Use of this file is governed by the Nemetschek Vectorworks SDK License Agreement
//	http://developer.vectorworks.net/index.php?title=Vectorworks_SDK_License
//

#include "StdAfx.h"

#include "ExtObj.h"
#include "Obj_ShapePane.h"

using namespace TesterModule;

namespace TesterModule
{
	// --------------------------------------------------------------------------------------------------------
	static SParametricDef gParametricDef = {
		/*LocalizedName*/			{"CExtObj", "LocalizedName"},
		/*SubType*/					kParametricSubType_Point,
		/*ResetOnMove*/				false,
		/*ResetOnRotate*/			false,
		/*WallInsertOnEdge*/		false,
		/*WallInsertNoBreak*/		false,
		/*WallInsertHalfBreak*/		false,
		/*WallInsertHideCaps*/		false,
	};

	static SParametricParamChc	gArrChoices[] = {
		{ 128,	"Line",					{"CExtObj", "param_p6_choice_line"} },
		{ 128,	"Arc",					{"CExtObj", "param_p6_choice_arc"} },
		{ 128,	"Bezier",				{"CExtObj", "param_p6_choice_bezier"} },
		{ 128,	"None",					{"CExtObj", "param_p6_choice_none"} },
		//------
		{ 129,	"Default",				{"CExtObj", "param_p7_choice_default"} },
		{ 129,	"Default Legend",		{"CExtObj", "param_p7_choice_defLegend"} },
		//------
		// TERMINATE
		{ NULL, NULL, {0,0} }
	};

	static SParametricParamDef gArrParameters[] = {
		{ "p1",			{"CExtObj", "param_p1_name"},		"False",	"False",	kFieldBoolean,		0 },
		{ "p2",			{"CExtObj", "param_p2_name"},		"False",	"False",	kFieldBoolean,		0 },
		{ "p3",			{"CExtObj", "param_p3_name"},		"",			"",			kFieldText,			0 },
		{ "p4",			{"CExtObj", "param_p4_name"},		"",			"",			kFieldText,			0 },
		{ "p5",			{"CExtObj", "param_p5_name"},		"2\"",		"2\"",		kFieldCoordDisp,	0 },
		{ "p6",			{"CExtObj", "param_p6_name"},		"Auto",		"Auto",		kFieldPopUp,		128 },
		{ "p7",			{"CExtObj", "param_p7_name"},		"Auto",		"Auto",		kFieldPopUp,		129 },
		{ "pAngle",		{"CExtObj", "param_pAngle_name"},	"15",		"15",		kFieldAngle,		0 },
		{ "pArea",		{"CExtObj", "param_pArea_name"},	"1",		"1",		kFieldArea,			0 },
		{ "pVolume",	{"CExtObj", "param_pVolume_name"},	"2",		"2",		kFieldVolume,		0 },
		{ "pClass",		{"CExtObj", "param_pClass_name"},	"None",		"None",		kFieldClassesPopup,	0 },
		{ "pLayer",		{"CExtObj", "param_pLayer_name"},	"",			"",			kFieldLayersPopup,	0 },
		// TERMINATE
		{ NULL, {0,0}, NULL, NULL, EFieldStyle(0), 0 }
	};
}

// --------------------------------------------------------------------------------------------------------
// {3CF3E0A7-1792-425C-88C0-07ACBE3E81F6}
IMPLEMENT_VWParametricExtension(
	/*Extension class*/	CExtObj,
	/*Event sink*/		CObj_EventSink,
	/*Universal name*/	"CExtObj_VWPluginWiz1",
	/*Version*/			1,
	/*UUID*/			0x3cf3e0a7, 0x1792, 0x425c, 0x88, 0xc0, 0x7, 0xac, 0xbe, 0x3e, 0x81, 0xf6 );
// Test:
// SetSelect(CreateCustomObject('CExtObj_VWPluginWiz1',0,0,0));

// --------------------------------------------------------------------------------------------------------
// --------------------------------------------------------------------------------------------------------
CExtObj::CExtObj(CallBackPtr cbp)
	: VWExtensionParametric( cbp, gParametricDef, gArrParameters, gArrChoices )
{
}

CExtObj::~CExtObj()
{
}

void CExtObj::DefineSinks()
{
	this->DefineSink<CObj_ShapePane>( IID_ProviderShapePane );
}

// --------------------------------------------------------------------------------------------------------
// --------------------------------------------------------------------------------------------------------
CObj_EventSink::CObj_EventSink(IVWUnknown* parent)
	: VWParametric_EventSink( parent )
{
}

CObj_EventSink::~CObj_EventSink()
{
}

EObjectEvent CObj_EventSink::OnInitXProperties(CodeRefID objectID)
{
	// obtain the interfact for accessing the extended properties
	using namespace VectorWorks::Extension;
	VCOMPtr<IExtendedProps>	extProps( IID_ExtendedProps );


	return kObjectEventNoErr;
}


EObjectEvent CObj_EventSink::Recalculate()
{
	VWPoint3D	offset( -500, 0, 0 );

	VWPolygon3DObj	poly;
	poly.AddVertex( offset + VWPoint3D(50, 100, 0) );
	poly.AddVertex( offset + VWPoint3D(1000, 0, 0) );
	poly.AddVertex( offset + VWPoint3D(1000, 1000, 0) );
	poly.AddVertex( offset + VWPoint3D(100, 800, 0) );
	poly.SetClosed( true );


	return kObjectEventNoErr;
}
